@@ -1627,7 +1627,7 @@ def waveSigmoidFunc(x, amp, t0, decay1, decay2, offset, linear):
 	out[int(t0):] = offset + amp * (np.exp(-decayRegion/decay1)-np.exp(-decayRegion/decay2))
 	return out
 
-def extractRiseTimes(waveforms, low=0.1, high=0.1, smooth=None, pretrigger=800):
+def extractRiseTimes(waveforms, low=0.1, high=0.9, smooth=None, pretrigger=800):
 	"""
 	This function extracts rise times from waveforms passed to it. his function does so by using threshold cross
 	methods. If a fit method is desired, see the fitWaveforms function instead. 
@@ -1685,8 +1685,8 @@ def extractRiseTimes(waveforms, low=0.1, high=0.1, smooth=None, pretrigger=800):
 		def findCrossPoints(wave):
 			maxval = np.max(wave)
 			maxloc = np.argmax(wave)
-			upperCross = maxval * upper
-			lowerCross = maxval * lower
+			upperCross = maxval * high
+			lowerCross = maxval * low
 			upCrossPoint = None
 			lowCrossPoint = None
 			i = maxloc
