@@ -188,7 +188,7 @@ def parseWaveformFiles(directory, run, subrun, headertype):
 	This function parses the input waveform files and creates arrays for each waveform type. 
 	It does this in a way that allows for differing waveform lengths per event type
 	'''
-	files = glob.glob(directory+'Run'+str(run)+'_'+str(subrun)+'*.wave')
+	files = glob.glob(directory+'Run'+str(run)+'_'+str(subrun)+'RIO*.wave')
 	singles = []
 	singlesChecksums = []
 	coincidences = []
